# EXTRA_IMAGE_FEATURES allows extra packages to be added to the generated images 
# (Some of these are automatically added to certain image types)
# "dbg-pkgs"     - add -dbg packages for all installed packages
#                  (adds symbol information for debugging/profiling)
# "dev-pkgs"     - add -dev packages for all installed packages
#                  (useful if you want to develop against libs in the image)
# "tools-sdk"      - add development tools (gcc, make, pkgconfig etc.)
# "tools-debug"    - add debugging tools (gdb, strace)
# "tools-profile"  - add profiling tools (oprofile, exmap, lttng valgrind (x86 only))
# "tools-testapps" - add useful testing tools (ts_print, aplay, arecord etc.)
# "debug-tweaks"   - make an image for suitable of development
#                    e.g. ssh root access has a blank password
# There are other application targets too, see meta/classes/core-image.bbclass 
# and meta/packages/tasks/task-core.bb for more details.

EXTRA_IMAGE_FEATURES = "tools-debug tools-profile tools-testapps debug-tweaks"

# A list of packaging systems used in generated images
# The first package type listed will be used for rootfs generation
# include 'package_deb' for debs
# include 'package_ipk' for ipks
# include 'package_rpm' for rpms
#PACKAGE_CLASSES ?= "package_rpm package_deb package_ipk"
PACKAGE_CLASSES ?= "package_ipk"

# mklibs library size optimization is more useful to smaller images,
# and less useful for bigger images. Also mklibs library optimization
# can break the ABI compatibility, so should not be applied to the
# images which are to be extended or upgraded later.
#This enabled mklibs library size optimization just for the specified image.
#MKLIBS_OPTIMIZED_IMAGES ?= "core-image-minimal"
#This enable mklibs library size optimization will be for all the images.
#MKLIBS_OPTIMIZED_IMAGES ?= "all"

# A list of additional classes to use when building the system
# include 'image-mklibs' to reduce shared library files size for an image
# include 'image-prelink' in order to prelink the filesystem image
# include 'image-swab' to perform host system intrusion detection
# NOTE: if listing mklibs & prelink both, then make sure mklibs is before prelink
USER_CLASSES ?= "image-mklibs image-prelink"

# The following are used to control options related to debugging.
#
# Uncomment this to change the optimization to make debugging easer, at the 
# possible cost of performance.
# DEBUG_BUILD = "1"
#
# Uncomment this to disable the stripping of the installed binaries
# INHIBIT_PACKAGE_STRIP = "1"
#
# Uncomment this to disable the split of the debug information into -dbg files
# INHIBIT_PACKAGE_DEBUG_SPLIT = "1"
#
# When splitting debug information, the following controls the results of the
# file splitting.
#
#  .debug (default):
#    When splitting the debug information will be placed into
#    a .debug directory in the same dirname of the binary produced:
#      /bin/foo -> /bin/.debug/foo
#
#  debug-file-directory:
#    When splitting the debug information will be placed into
#    a central debug-file-directory, /usr/lib/debug:
#      /bin/foo -> /usr/lib/debug/bin/foo.debug
#
#    Any source code referenced in the debug symbols will be copied
#    and made available within the /usr/src/debug directory
#
PACKAGE_DEBUG_SPLIT_STYLE = '.debug'
# PACKAGE_DEBUG_SPLIT_STYLE = 'debug-file-directory'

# Uncomment these to build a package such that you can use gprof to profile it.
# NOTE: This will only work with 'linux' targets, not
# 'linux-uclibc', as uClibc doesn't provide the necessary
# object files.  Also, don't build glibc itself with these
# flags, or it'll fail to build.
#
# PROFILE_OPTIMIZATION = "-pg"
# SELECTED_OPTIMIZATION = "${PROFILE_OPTIMIZATION}"
# LDFLAGS =+ "-pg"

# Set this if you wish to make pkgconfig libraries from your system available 
# for native builds. Combined with extra ASSUME_PROVIDEDs this can allow 
# native builds of applications like oprofileui-native (unsupported feature).
#EXTRA_NATIVE_PKGCONFIG_PATH = ":/usr/lib/pkgconfig"

ENABLE_BINARY_LOCALE_GENERATION = "1"

# The architecture to build SDK items for, by setting this you can build SDK
# packages for architectures other than the host i.e. building i686 packages
# on an x86_64 host.
# Supported values are i686 and x86_64
#SDKMACHINE ?= "i686"

# Set GLIBC_GENERATE_LOCALES to the locales you wish to generate should you not
# wish to perform the time-consuming step of generating all LIBC locales.
# NOTE: If removing en_US.UTF-8 you will also need to uncomment, and set
# appropriate values for IMAGE_LINGUAS and LIMIT_BUILT_LOCALES
# WARNING: this may break localisation!
#GLIBC_GENERATE_LOCALES = "en_GB.UTF-8 en_US.UTF-8"
# See message above as to whether setting these is required
#IMAGE_LINGUAS ?= "en-gb"
#LIMIT_BUILT_LOCALES ?= "POSIX en_GB"

# This value is currently used by PSEUDO to determine if the recipe should
# build both the 32-bit and 64-bit wrapper libraries on a 64-bit build system.
#
# PSEUDO will attempt to determine if a 32-bit wrapper is necessary, but 
# it doesn't always guess properly.  If you have 32-bit executables on 
# your 64-bit build system, you likely want to set this to "0", 
# otherwise you could end up with incorrect file attributes on the 
# target filesystem.
#
# Default to not build 32 bit libs on 64 bit systems, comment this
# out if that is desired
NO32LIBS = "1"

DISTRO = "micro"
INHERIT += "sstate rm_old_work brightsign_source_release"
INHERIT_append_virtclass-native = "rm_work"
DISTRO_FEATURES_append = " directfb"

# Sink meta-oe below oe-core
BBFILE_PRIORITY_openembedded-layer = "1"

PREFERRED_PROVIDER_virtual/libgl = "nexus"
BBMASK = "(mesa/mesa|xorg-lib/lib)"

export CCACHE_DIR

BS_DEBUG ?= "1"
BS_TIMEDOCTOR ?= "1"

LINUXLIBCVERSION = "2.6.39"
OPKGBUILDCMD = "opkg-build"

# This is set to ensure that we have enough room in the partition for
# a few bad blocks and for more to develop in the field. See genparts.sh.
KERNEL_IMAGE_MAXSIZE = 3407872

# This is set to ensure that we can cope with a few bad blocks already
# in the chip but none to develop in the field. See genparts.sh.
RESCUE_IMAGE_MAXSIZE = 5242880

# Suffixes to add to PACKAGE_ARCH etc. to indicate the particular
# variant we're building.
BS_DEBUG_SUFFIX = "${@base_conditional('BS_DEBUG', '1', '-debug', '', d)}"
BS_TIMEDOCTOR_SUFFIX = "${@base_conditional('BS_TIMEDOCTOR', '1', '-td', '', d)}"
BS_ALL_SUFFIXES = "${BS_TIMEDOCTOR_SUFFIX}${BS_DEBUG_SUFFIX}"

PACKAGE_ARCHS .= "${@base_conditional('BS_TIMEDOCTOR', '1', ' ${MACHINE}-td', '', d)}${@base_conditional('BS_DEBUG', '1', ' ${MACHINE}-debug', '', d)}"
PACKAGE_ARCHS .= "${@base_contains('BS_ALL_SUFFIXES', '-td-debug', ' ${MACHINE}-td-debug', '', d)}"

export GZIP = "-1"

IMAGE_NAME = "${IMAGE_BASENAME}-${MACHINE}${BS_ALL_SUFFIXES}"
IMAGE_LINK_NAME = "${IMAGE_NAME}"
